======
CRUTCH
======

.. image:: https://badge.fury.io/py/crutch.svg
    :target: https://badge.fury.io/py/crutch
    :alt: PyPi version

.. image:: https://travis-ci.org/m4yers/crutch.svg?branch=master
    :target: https://travis-ci.org/m4yers/crutch
    :alt: Build status

.. image:: https://coveralls.io/repos/github/m4yers/crutch/badge.svg?branch=master
    :target: https://coveralls.io/github/m4yers/crutch?branch=master
    :alt: Test coverage

.. image:: https://landscape.io/github/m4yers/crutch/master/landscape.svg?style=flat
   :target: https://landscape.io/github/m4yers/crutch/master
   :alt: Code Health

Have you ever had this moment when you wanted to write a small tool or just try
some new algorithm but the thought of assembling a proper project folder
structure spoiled the desire...

Crutch is a small-size project generator that allows you to create, build and
test a project

.. contents::

Installation
============

From pip::

  $ pip install crutch


Usage
=====

To create a project within an existing directory::

  $ crutch new <type>

To build and test the project within its directory::

  $ crutch build


Types
-------------

In Progress::

  cpp
  python

In Future::

  c#
  java
  vim
  ...


Links
=====

* PyPI_
* GitHub_
* `Travis CI`_
* Coveralls_

.. _PyPI: https://pypi.python.org/pypi/crutch/
.. _GitHub: https://github.com/m4yers/crutch
.. _`Travis CI`: https://travis-ci.org/m4yers/crutch
.. _`Coveralls`: https://coveralls.io/r/m4yers/crutch
